summaryrefslogtreecommitdiffstats
path: root/mpeglib/lib/output/outputStream.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-08-10 22:19:39 +0000
commit27edf28be2772229a7974a007313ea30d92c3ffd (patch)
tree14b9842bbd90c801d89ad5ddb38831fdf8aec1a4 /mpeglib/lib/output/outputStream.h
parent7ef01c0f34d9c6732d258154bcd3ba5a88280db9 (diff)
downloadtdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.tar.gz
tdemultimedia-27edf28be2772229a7974a007313ea30d92c3ffd.zip
rename the following methods:
tqparent parent tqmask mask git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdemultimedia@1246260 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'mpeglib/lib/output/outputStream.h')
-rw-r--r--mpeglib/lib/output/outputStream.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/mpeglib/lib/output/outputStream.h b/mpeglib/lib/output/outputStream.h
index 6dccd02e..9ef538fd 100644
--- a/mpeglib/lib/output/outputStream.h
+++ b/mpeglib/lib/output/outputStream.h
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
// we return the tqmask which triggerd (by "AND")
// or the current polled tqmask when method is POLL
// Note: you can only wait for "true" signals
- virtual int waitStreamState(int method,int tqmask,int streamType);
+ virtual int waitStreamState(int method,int mask,int streamType);
@@ -105,10 +105,10 @@ class KDE_EXPORT OutputStream {
// stream State handling
- // we return the tqmask which triggerd (by "AND")
- // or the current polled tqmask when method is POLL
+ // we return the mask which triggerd (by "AND")
+ // or the current polled mask when method is POLL
// Note: you can only wait for "true" signals